summaryrefslogtreecommitdiff
path: root/include/mbgl/storage
diff options
context:
space:
mode:
Diffstat (limited to 'include/mbgl/storage')
-rw-r--r--include/mbgl/storage/offline.hpp13
1 files changed, 7 insertions, 6 deletions
diff --git a/include/mbgl/storage/offline.hpp b/include/mbgl/storage/offline.hpp
index dd63cf968f..2bc286dbab 100644
--- a/include/mbgl/storage/offline.hpp
+++ b/include/mbgl/storage/offline.hpp
@@ -99,20 +99,21 @@ public:
/**
* The number of resources that are known to be required for this region. See the
* documentation for `requiredResourceCountIsIndeterminate` for an important caveat
* about this number.
*/
uint64_t requiredResourceCount = 0;
/**
* This property is true during early phases of an offline download, when the total
* required resource count is unknown and requiredResourceCount is merely a lower
* bound.
*
- * Specifically, it is true before until the style and tile sources have been
- * downloaded, and false thereafter.
+ * Specifically, it is false during early phases of an offline download. Once
+ * style and tile sources have been downloaded, it is possible to calculate the
+ * precise number of required resources, at which point it is set to true.
*/
- bool requiredResourceCountIsIndeterminate = true;
+ bool requiredResourceCountIsPrecise = false;
bool complete() const {
return completedResourceCount == requiredResourceCount;
@@ -99,20 +99,21 @@ public:
/**
* The number of resources that are known to be required for this region. See the
- * documentation for `requiredResourceCountIsIndeterminate` for an important caveat
+ * documentation for `requiredResourceCountIsPrecise` for an important caveat
* about this number.
*/
@@ -99,20 +99,21 @@ public:
uint64_t requiredResourceCount = 0;
/**
- * This property is true during early phases of an offline download, when the total
- * required resource count is unknown and requiredResourceCount is merely a lower
+ * This property is true when the value of requiredResourceCount is a precise
+ * count of the number of required resources, and false when it is merely a lower
* bound.
*